        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 23 <strong>control</strong><br>0,5,10,12,14,17,18,19,20,24,26,27,28,29,30,33,41,42,44,45,46,48,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>38</strong> miembros: 15 <br>1,2,3,4,6,11,15,16,22,32,36,37,38,39,40';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 13 <br>7,8,9,13,21,23,25,31,34,35,43,47,49';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 23 <strong>control</strong><br>0,5,10,12,14,17,18,19,20,24,26,27,28,29,30,33,41,42,44,45,46,48,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>38</strong> miembros: 15 <br>1,2,3,4,6,11,15,16,22,32,36,37,38,39,40';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 13 <br>7,8,9,13,21,23,25,31,34,35,43,47,49';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 23 <strong>control</strong><br>0,5,10,12,14,17,18,19,20,24,26,27,28,29,30,33,41,42,44,45,46,48,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>38</strong> miembros: 15 <br>1,2,3,4,6,11,15,16,22,32,36,37,38,39,40';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 13 <br>7,8,9,13,21,23,25,31,34,35,43,47,49';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 23 <strong>control</strong><br>0,5,10,12,14,17,18,19,20,24,26,27,28,29,30,33,41,42,44,45,46,48,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>38</strong> miembros: 15 <br>1,2,3,4,6,11,15,16,22,32,36,37,38,39,40';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 13 <br>7,8,9,13,21,23,25,31,34,35,43,47,49';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 23 <strong>control</strong><br>0,5,10,12,14,17,18,19,20,24,26,27,28,29,30,33,41,42,44,45,46,48,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>38</strong> miembros: 15 <br>1,2,3,4,6,11,15,16,22,32,36,37,38,39,40';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 13 <br>7,8,9,13,21,23,25,31,34,35,43,47,49';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>24</strong> miembros: 23 <strong>control</strong><br>0,5,10,12,14,17,18,19,20,24,26,27,28,29,30,33,41,42,44,45,46,48,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>38</strong> miembros: 15 <br>1,2,3,4,6,11,15,16,22,32,36,37,38,39,40';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260609 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>7</strong> miembros: 13 <br>7,8,9,13,21,23,25,31,34,35,43,47,49';}
}
